@@ -53,7 +53,7 @@ from django.conf import settings
 
 PLUGIN_SETTINGS = settings.PLUGINS_CONFIG.get("config_officer", dict())
 NETBOX_DEVICES_CONFIGS_DIR = PLUGIN_SETTINGS.get("NETBOX_DEVICES_CONFIGS_DIR", "/device_configs")
-TIME_ZONE = os.environ.get("TIME_ZONE", "Europe/Moscow")
+TIME_ZONE = os.environ.get("TIME_ZONE", "UTC")
 
 
 def global_collection():
@@ -486,4 +486,4 @@ def running_config(request, hostname):
         message["status"] = True
         message["running_config"] = running_config
     message["repo_state"] = get_file_repo_state(NETBOX_DEVICES_CONFIGS_DIR, f"{hostname}_running.txt")
-    return render(request, "config_officer/device_runnig_config.html", {"message": message})
\ No newline at end of file
+    return render(request, "config_officer/device_running_config.html", {"message": message})
\ No newline at end of file
